Annotation

Struct Annotation 

pub struct Annotation {
    pub header: Option<String>,
    pub text: Option<String>,
    pub severity: Severity,
    /* private fields */
}
Info about annotation. You can create these manually and then pass to AnnotationList::add or just use AnnotationLists helper methods

Fields

header: Option<String>

header will be shown above error message

text: Option<String>

text will be shown near annotated fragment. Note that fragment will be highlighted even if text is None. To disable this, pass a zero length range when creating the annotation.

severity: Severity

Implementations

Source

impl Annotation

pub fn new( range: Range<usize>, severity: Severity, header: impl AnnotationText, text: impl AnnotationText, ) -> Result<Self>

Create new annotation. Will return Error::InvalidRange if provided range has start > end. You can pass &str, String or Option<String> as header and text arguments.

assert_eq!(
    Annotation::new(0..5, Severity::Info, "header", "text").unwrap(),
    Annotation::new(
        0..5, Severity::Info, Some("header".into()), Some("text".into())
    ).unwrap()
);
assert!(Annotation::new(0..5, Severity::Warning, None, None).is_ok());
assert_eq!(
    Annotation::new(5..0, Severity::Info, "h", "t"), Err(Error::InvalidRange(5, 0))
);
pub fn info( range: Range<usize>, header: impl AnnotationText, text: impl AnnotationText, ) -> Result<Self>

Create a new Severity::Info annotation

pub fn warning( range: Range<usize>, header: impl AnnotationText, text: impl AnnotationText, ) -> Result<Self>

Create a new Severity::Warning annotation

pub fn error( range: Range<usize>, header: impl AnnotationText, text: impl AnnotationText, ) -> Result<Self>

Create a new Severity::Error annotation

pub fn range(&self) -> &Range<usize>

Get annotations range